#
# spec file for package perl-DBI (Version 1.609)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

%bcond_with test

Name:           perl-DBI
%define cpan_name %( echo %{name} | %{__sed} -e 's,perl-,,' )
Summary:        The Perl Database Interface
Version:        1.609
Release:        7.6
License:        GPLv2+
Group:          Development/Libraries/Perl
Url:            http://cpan.org/modules/by-module/DBI/
Source:         %{cpan_name}-%{version}.tar.bz2
%if 0%{?rhel_version} || 0%{?centos_version}
AutoReq:        off
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::Simple) >= 0.40
%if %{with test}
BuildRequires:  perl(Test::Pod) >= 1.00
BuildRequires:  perl(Test::Pod::Coverage) >= 1.04
%endif
#
BuildRequires:  perl(Storable) >= 1
BuildRequires:  perl(File::Spec)
BuildRequires:  perl(Scalar::Util)
#BuildRequires:  perl(Curses)
Requires:       perl(Storable) >= 1
Requires:       perl(File::Spec)
Requires:       perl(Scalar::Util)
Requires:       perl-PlRPC
%{perl_requires}
Obsoletes:      perl_dbi
Provides:       perl_dbi DBI DBDI

%description
The Perl Database Interface by Tim Bunce.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL OPTIMIZE="$RPM_OPT_FLAGS -Wall"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%clean
%{__rm} -rf $RPM_BUILD_ROOT

%files -f %{name}.files
%defattr(-,root,root)
%doc Changes README

%changelog
* Sat Aug 27 2011 chris@computersalat.de
- fix build for CentOS, RHEL
- remove Author from desc
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Tue Oct 13 2009 chris@computersalat.de
- cleanup spec
  o removed some obsolete defines
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Thu Jun 18 2009 chris@computersalat.de
- spec fix for perl-macros
* Thu Jun 18 2009 chris@computersalat.de
- added perl-macros
  o autogen filelist with perl_gen_filelist
* Mon Jun 15 2009 chris@computersalat.de
- update to 1.609
  * Fixes to DBD::File (H.Merijn Brand)
    added f_schema attribute
    table names case sensitive when quoted, insensitive when unquoted
    workaround a bug in SQL::Statement (temporary fix) related
    to the "You passed x parameters where y required" error
  * Added ImplementorClass and Name info to the "Issuing rollback() due to
    DESTROY without explicit disconnect" warning to identify the handle.
    Applies to compiled drivers when they are recompiled.
  * Added DBI->visit_handles($coderef) method.
  * Added $h->visit_child_handles($coderef) method.
  * Added docs for column_info()'s COLUMN_DEF value.
  * Clarified docs on stickyness of data type via bind_param().
  * Clarified docs on stickyness of data type via bind_col().
- some spec mods
* Mon May 18 2009 anicka@suse.cz
- update to 1.608
  * Fixes to DBD::File (H.Merijn Brand)
    bind_param () now honors the attribute argument
    added f_ext attribute
    File::Spec is always required. (CORE since 5.00405)
    Fail and set errstr on parameter count mismatch in execute ()
  * Fixed two small memory leaks when running in mod_perl
    one in DBI->connect and one in DBI::Gofer::Execute.
    Both due to "local $ENV{...};" leaking memory.
  * Fixed DBD_ATTRIB_DELETE macro for driver authors
    and updated DBI::DBD docs thanks to Martin J. Evans.
  * Fixed 64bit issues in trace messages thanks to Charles Jardine.
  * Fixed FETCH_many() method to work with drivers that incorrectly
  return an empty list from $h->FETCH. Affected gofer.
  * Added 'sqlite_' as registered prefix for DBD::SQLite.
  * Corrected many typos in DBI docs thanks to Martin J. Evans.
  * Improved DBI::DBD docs thanks to H.Merijn Brand.
* Fri Jul 25 2008 anicka@suse.cz
- update to 1.607
  * NOTE: Perl 5.8.1 is now the minimum supported version.
  * Fixed missing import of carp in DBI::Gofer::Execute.
  * Added note to docs about effect of execute(@empty_array).
  * Clarified docs for ReadOnly thanks to Martin Evans.
* Fri Jun 27 2008 anicka@suse.cz
- update to 1.605
  * Fixed broken DBIS macro with threads on big-endian machines
    with 64bit ints but 32bit pointers.
  * Fixed the selectall_arrayref, selectrow_arrayref, and
    selectrow_array methods that get embedded into compiled drivers
    to use the inner sth handle when passed a $sth instead of an
    sql string. Drivers will need to be recompiled to pick up
    this change.
  * Fixed leak in neat() for some kinds of values
  * Fixed DBI::PurePerl neat() to behave more like XS neat().
  * Increased default $DBI::neat_maxlen from 400 to 1000.
  * Increased timeout on tests to accomodate very slow systems.
  * other minor improvements and fixes
  - remove -dbis patch (fixed in upstream)
* Wed Mar 26 2008 anicka@suse.cz
- update to 1.604
  * Fixed fetchall_arrayref with $max_rows argument broken
  in 1.603
* Mon Mar 24 2008 anicka@suse.cz
- update to 1.603
  * Fixed pure-perl fetchall_arrayref with $max_rows argument
    to not error when fetching after all rows already fetched.
  * Fixed C sprintf formats and casts, fixing compiler warnings.
  * Changed dbi_profile() to accept a hash of profiles
    and apply to all.
  * Changed gofer stream transport to improve error reporting.
  * Changed gofer test timeout to avoid spurious failures
    on slow systems.
  * Added options to t/85gofer.t so it's more useful for
    manual testing.
* Thu Feb 21 2008 anicka@suse.cz
- update to 1.602
  * bugfixes
  * test and documentation enhancements
* Thu Nov  1 2007 anicka@suse.cz
- update to 1.601
  * Fixed t/05thrclone.t to work with Test::More >= 0.71
  * Fixed DBI for VMS thanks to Peter (Stig) Edwards.
  * Added client-side caching to DBD::Gofer.
  * Added DBI::Util::CacheMemory for use with DBD::Gofer caching.
* Mon Oct  8 2007 anicka@suse.cz
- update to 1.59
  * Added check_response_sub to DBI::Gofer::Execute
  * bugfixes. test fixes
* Tue Jul  3 2007 anicka@suse.cz
- update to 1.58
  * Fixed code triggering fatal error in bleadperl
  * Fixed compiler warning
  * values than before *if* your perl was built with 64-bit
  'int' type (i.e. "perl -V:intsize" says intsize='8').
  * Fixed XS versions of select*_*() methods to call execute()
  fetch() etc., with inner handle instead of outer.
  * Fixed execute_for_fetch() to not cache errstr values
  * Fixed unused var compiler warning thanks to JDHEDDEN.
  * Changed DBI::hash to return 'I32' type instead of 'int' so results
  are portable/consistent regardless of size of the int type.
  * test fixes, added documenttion
* Mon Jun 11 2007 anicka@suse.cz
- update to 1.56
  * bugfixes, documentation fixes, test fixes
  * Added DBI_GOFER_RANDOM env var that can be use to trigger random
  failures and delays when executing gofer requests.
  * Added more functionality to the (undocumented) Callback mechanism.
  * Added $h->{ReadOnly} attribute.
  * Added support for DBI Profile Path to contain refs to scalars
  which will be de-ref'd for each profile sample.
  * Added dbilogstrip utility to edit DBI logs for diff'ing (gets installed)
  * Added details for SQLite 3.3 to NULL handling docs thanks to Alex Teslik.
  * Added take_imp_data() to DBI::PurePerl.
  * many gofer related changes
* Mon Feb 26 2007 anicka@suse.cz
- update to 1.54
  * Added new DBD::Gofer 'stateless proxy' driver and framework,
  * and the DBI test suite is now also executed via DBD::Gofer,
  * and DBD::Gofer+DBI::PurePerl, in addition to DBI::PurePerl.
  * Added ability for trace() to support filehandle argument,
  * including tracing into a string, thanks to Dean Arnold.
  * Added ability for drivers to implement func() method
  * so proxy drivers can proxy the func method itself.
  * Added SQL_BIGINT type code
  * Added $h->private_attribute_info method.
* Wed Dec 13 2006 anicka@suse.cz
- update to 1.53
  * Fixed checks for weaken to work with early 5.8.x versions
  * Fixed DBD::Proxy handling of some methods, including commit
    and rollback.
  * Fixed to be more robust against drivers not handling multiple
    result sets properly.
  * Test fixes.
  * Added array context support to execute_array and
    execute_for_fetch methods which returns executed tuples
    and rows affected.
  * Added Tie::Cache::LRU example to docs
* Wed Sep 13 2006 anicka@suse.cz
- update to 1.52
  * fixed several memory leaks
  * changes and additions to profiling
* Wed Jul 12 2006 anicka@suse.cz
- update to 1.51
  * many bugfixes, see upstream changelog
* Mon Mar 27 2006 mls@suse.de
- set DBIS in a way compatible to the header file, fixes
  use64bit issue [#155067]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan  3 2006 anicka@suse.cz
- update to 1.50
* Mon Aug  1 2005 cthiel@suse.de
- update to version 1.48
* Tue Jul 26 2005 anicka@suse.cz
- add perl-PlRPC to Requires
* Thu Feb 17 2005 mjancar@suse.cz
- update to 1.47
* Fri Aug  6 2004 mjancar@suse.cz
- update to 1.43
* Thu Feb 26 2004 mjancar@suse.cz
- update to 1.41
* Tue Oct 21 2003 mjancar@suse.cz
- update to 1.38
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Mon Jun 16 2003 mjancar@suse.cz
- fix filelist
* Thu Jun  5 2003 mjancar@suse.cz
- fix test failing on 64bit architectures
* Wed Jun  4 2003 mjancar@suse.cz
- update to 1.37
  * Changed execute_array() return value from row
    count to executed tuple count, and now the
    ArrayTupleStatus attribute is mandatory.
- use $RPM_OPT_FLAGS
- don't package MANIFEST
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Fri Dec 13 2002 prehak@suse.cz
- update to version 1.32
* Tue Jul  9 2002 prehak@suse.cz
- updated to version 1.28
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Tue Jan 22 2002 rvasice@suse.cz
- update to version 1.20
* Tue Aug 14 2001 rvasice@suse.cz
- update to version 1.19
- spec file cleanup
* Tue Feb 13 2001 cihlar@suse.cz
- bzipped sources
- use %%{version}
- update to version 1.14
- added %%clean
- fixed file list
- added make test
* Tue Nov  7 2000 grimmer@suse.de
- removed BuildRoot path via sed calls in spec file
* Tue Oct 31 2000 grimmer@suse.de
- renamed from perl_dbi to perl-DBI
- added BuildRoot
* Wed Jul  5 2000 grimmer@suse.de
- marked man pages as documentation
- added missing man pages from section 1
- added Group tag
- added "Provides: DBI"
* Wed May 24 2000 ug@suse.de
- added to distribution
